limbdark
========

C/Theano/Python implementation of the [Limbdark.jl](https://github.com/rodluger/Limbdark.jl)
code for analytic limb darkening occultation light curves (Agol, Luger, Foreman-Mackey 2019).

C/Theano interface adapted from Dan Foreman-Mackey's [exoplanet](https://github.com/dfm/exoplanet)
package. C implementation of the Limbdark equations written by Rodrigo Luger, adapted
from Eric Agol's Julia code.
